@@ -75,7 +75,7 @@ impl MoveType {
                                 Color::NoColor => sq,
                             }
                         };
-                        &(&bb & &position.color_bb[p.color.flip().index()]) | &square_bb(sq)
+                        &(&bb & &position.color_bb[p.color.flip().index()]) | &(&square_bb(sq) & &!&position.color_bb[2])
                     } else {
                         bb
                     }
@@ -1542,9 +1542,10 @@ pub mod tests {
         let cases = [
             ("f2", PieceType::Rook, Color::White, 13),
             ("e7", PieceType::Knight, Color::Black, 7),
+            ("f6", PieceType::Pawn, Color::Black, 0)
         ];
         let mut pos = Position::new();
-        pos.set_sfen("57/5R5K/57/57/3b1L04k1/55b1/4n7/57/55R1/57/57/57 w - 1")
+        pos.set_sfen("57/5R5K/57/57/3b1L04k1/5p4b1/4n7/57/55R1/57/57/57 w - 1")
             .expect("failed to parse SFEN string");
         for case in cases {
             let bb = pos.move_candidates(
@@ -1975,7 +1976,7 @@ pub mod tests {
     }
 
     #[test]
-    fn place() {
+    fn place_king() {
         setup();
         let mut position_set = Position::default();
         position_set
@@ -2022,6 +2023,19 @@ pub mod tests {
         assert_eq!(position_set.get_hand(Color::Black), "rrbn");
     }
 
+    #[test]
+    fn place_in_check() {
+        setup();
+        let black_fen = "5KQ2L02/9L02/57/57/3L08/5L06/2L09/2L09/8L03/57/9L02/6k5 b qrn2pN2P 3";
+        let cases = [PieceType::Queen, PieceType::Pawn];
+        for case in cases {
+            let mut position_set = Position::default();
+            position_set.set_sfen(black_fen);
+            position_set.place(Piece {piece_type: case, color: Color::Black},G11);
+            assert_eq!(position_set.ply(), 4);
+        }
+    }
+
     #[test]
     fn empty_squares_with_plinths() {
         setup();
